# Vizu - the simple CSV-viewer

Doing advanced analysis of data in CSV-format can be done with many tools - Excel and Pandas are two popular choises.
However, to quickly browse through the data for simple analysis and exploration, you will need more button-clicks than you should. 

`vizu` is meant to bridge the gap by providing a simple UI to browse a CSV file.

It uses the excellent libraries `dash` and `pandas` under the hood for GUI and data manipulation, respectively.

### Installation
`pip install vizu`

### Browse your first .csv file
Run the following command in a terminal

`vizu path/to/file.csv`

and go to your browser via the link it outputs.
